summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pminteriortextureedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pminteriortextureedit.h')
-rw-r--r--kpovmodeler/pminteriortextureedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pminteriortextureedit.h b/kpovmodeler/pminteriortextureedit.h
index ab46142d..a576c926 100644
--- a/kpovmodeler/pminteriortextureedit.h
+++ b/kpovmodeler/pminteriortextureedit.h
@@ -34,12 +34,13 @@ class PMInteriorTexture;
class PMInteriorTextureEdit : public PMTextureBaseEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMTextureEdit with parent and name
*/
- PMInteriorTextureEdit( TQWidget* parent, const char* name = 0 );
+ PMInteriorTextureEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -34,12 +34,13 @@ class PMInteriorTexture;
public:
/**
- * Creates a PMTextureEdit with parent and name
+ * Creates a PMTextureEdit with tqparent and name
*/